@@ -17,8 +17,10 @@ scrape_abs_catalogues <- function() {
 
   # Scrape the main ABS statistics page
   stats_page_file <- tempfile(fileext = ".html")
-  dl_file(url = "https://www.abs.gov.au/statistics",
-          destfile = stats_page_file)
+  dl_file(
+    url = "https://www.abs.gov.au/statistics",
+    destfile = stats_page_file
+  )
 
   abs_stats_page <- xml2::read_html(stats_page_file)
 
@@ -42,10 +44,11 @@ scrape_abs_catalogues <- function() {
   # scrape each page
 
   scrape_sub_page <- function(heading, sub_page_url_suffix) {
-
     sub_page_file <- tempfile(fileext = ".html")
-    dl_file(url = glue::glue("https://www.abs.gov.au{sub_page_url_suffix}"),
-            destfile = sub_page_file)
+    dl_file(
+      url = glue::glue("https://www.abs.gov.au{sub_page_url_suffix}"),
+      destfile = sub_page_file
+    )
 
     sub_page <- xml2::read_html(sub_page_file)
 
@@ -72,9 +75,12 @@ scrape_abs_catalogues <- function() {
   }
 
 
-  new_abs_lookup_table <- purrr::map2_dfr(.x = main_page_data$heading,
-                                          .y = main_page_data$url_suffix,
-                                          scrape_sub_page)
+  new_abs_lookup_table <- purrr::map2_dfr(
+    .x = main_page_data$heading,
+    .y = main_page_data$url_suffix,
+    scrape_sub_page
+  )
 
-  new_abs_lookup_table
+  new_abs_lookup_table %>%
+    filter(.data$catalogue != "")
 }
